# django-org

[![GitHub Actions](https://github.com/pikhovkin/django-org/workflows/build/badge.svg)](https://github.com/pikhovkin/django-org/actions)
[![PyPI](https://img.shields.io/pypi/v/django-org.svg)](https://pypi.org/project/django-org/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/django-org.svg)
[![framework - Django](https://img.shields.io/badge/framework-Django-0C3C26.svg)](https://www.djangoproject.com/)
![PyPI - Django Version](https://img.shields.io/pypi/djversions/django-org.svg)
[![PyPI - License](https://img.shields.io/pypi/l/django-org)](./LICENSE)

Base classes for enterprise modeling

### Installation

```bash
$ pip install django-org
```

Install with `django-easy-select2`
```bash
$ pip install django-org[select2]
```

### Usage

```python

```

### License

MIT
